picuplib
=========

Small python library for uploading pictures to `picflash.org`_

.. _picflash.org: https://picflash.org

Documentation can be found on ReadTheDocs_

.. _ReadTheDocs: http://picuplib.readthedocs.org/en/latest/

Requirements
------------

- Python 3
    * Python 2.6 or greater should work too but is not realy tested

- requests

Installation
============

#. Download and unpack the tarball or clone the repo
#. type ``python setup.py install``

or just use pip
